/*
 * Project name:
     GLCD_Test (Demonstration of the GLCD library routines)
 * Copyright:
     (c) Mikroelektronika, 2007.
 * Revision History:
     20071210:
       - initial release;
 * Description:
     This is a simple demonstration of the GLCD library routines:
     - Init and Clear (pattern fill)
     - Image display
     - Basic geometry - lines, circles, boxes and rectangles
     - Text display and handling
 * Test configuration:
     MCU:             AT89S8253
     Dev.Board:       Easy8051B
     Oscillator:      External Clock 10.0000 MHz
     Ext. Modules:    GLCD 128x64, KS108/107 controller
     SW:              mikroC for 8051 v1.0
 * Notes:
     - Turn GLCD backlight switch on Easy8051B board on.
*/

//Declarations------------------------------------------------------------------
const code char advanced8051_bmp[1024];
//--------------------------------------------------------------end-declarations

// Glcd module connections
sfr char GLCD_DataPort at P0;               // GLCD data port
                                                                                                                
sbit GLCD_CS1 at P2.B0;                     // GLCD chip select 1 signal 
sbit GLCD_CS2 at P2.B1;                     // GLCD chip select 2 signal
sbit GLCD_RS  at P2.B2;                     // GLCD register select signal
sbit GLCD_RW  at P2.B3;                     // GLCD read/write signal
sbit GLCD_RST at P2.B5;                     // GLCD reset signal
sbit GLCD_EN  at P2.B4;                     // GLCD enable signal
// End Glcd module connections

void delay2S(){                             // 2 seconds delay function
  delay_ms(2000);
}                 

void main() {                       
  unsigned short ii;                      
  char *someText;

  Glcd_Init();                              // Initialize GLCD
  Glcd_Fill(0x00);                          // Clear GLCD

  while(1) {
    Glcd_Image(advanced8051_bmp);           // Draw image
    delay2S(); delay2S();

    Glcd_Fill(0x00);

    Glcd_Box(62,40,124,56,1);               // Draw box
    Glcd_Rectangle(5,5,84,35,1);            // Draw rectangle
    Glcd_Line(0, 63, 127, 0,1);             // Draw line

    delay2S();

    for(ii = 5; ii < 60; ii+=5 ){           // Draw horizontal and vertical lines
      Delay_ms(250);
      Glcd_V_Line(2, 54, ii, 1);
      Glcd_H_Line(2, 120, ii, 1);
      }

    delay2S();

    Glcd_Fill(0x00);
    
    Glcd_Set_Font(Character8x8, 8, 8, 32);  // Choose font, see __Lib_GLCDFonts.c in Uses folder
    Glcd_Write_Text("mikroE", 5, 7, 2);     // Write string

    for (ii = 1; ii <= 10; ii++)            // Draw circles
      Glcd_Circle(63,32, 3*ii, 1);
    delay2S();

    Glcd_Box(12,20, 70,57, 2);              // Draw box
    delay2S();

    Glcd_Set_Font(FontSystem5x8, 5, 8, 32); // Change font
    someText = "BIG:ONE";                   
    Glcd_Write_Text(someText, 5,3, 2);      // Write string
    delay2S();

    someText = "SMALL:NOT:SMALLER";
    Glcd_Write_Text(someText, 20,5, 1);     // Write string
    delay2S();

  }

}
